- Raise ValueError when `sample_weight` contains only zero values to prevent
  meaningless input data during fitting. This change applies to all estimators that
  support the parameter `sample_weight`. This change also affects metrics that validate
  sample weights.
  By :user:`Lucy Liu <lucyleeow>` and :user:`John Hendricks <j-hendricks>`.
